@@ -8,7 +8,7 @@ from ..geometry import (
 )
 from .constants import (
     PAC_BYTES_TO_POSITIONING_MAP, COMMANDS, PAC_TAB_OFFSET_COMMANDS,
-    MICROSECONDS_PER_CODEWORD,
+    MICROSECONDS_PER_CODEWORD, INCONVERTIBLE_TO_ASCII_EXTENDED_CHARS_ASSOCIATION
 )
 
 PopOnCue = collections.namedtuple("PopOnCue", "buffer, start, end")
@@ -423,11 +423,21 @@ class InstructionNodeCreator:
 
         :type accented_character: str
         """
-        if self._collection and self._collection[-1].is_text_node() and \
-                self._collection[-1].text:
-            ascii_char = unicodedata.normalize('NFD', accented_character)\
-                .encode('ascii', 'ignore').decode("utf-8")
-            if ascii_char and self._collection[-1].text[-1] == ascii_char:
+        is_text_node = (
+                self._collection and
+                self._collection[-1].is_text_node() and
+                self._collection[-1].text
+                )
+        if is_text_node:
+            try:
+                ascii_char = [
+                    unicodedata.normalize('NFD', accented_character)
+                    .encode('ascii', 'strict').decode("utf-8")
+                ]
+            except (UnicodeEncodeError, UnicodeDecodeError):
+                ascii_char = INCONVERTIBLE_TO_ASCII_EXTENDED_CHARS_ASSOCIATION.get(accented_character)
+
+            if ascii_char and self._collection[-1].text[-1] in ascii_char:
                 self._collection[-1].text = self._collection[-1].text[:-1]
 
 
